@@ -1,17 +1,20 @@
+pub mod level;
 pub mod term_status;
 pub mod text;
+pub mod utils;
 
-use crate::task_tree::TaskInternal;
-use std::sync::Arc;
+pub use level::Level;
 pub use term_status::TermStatus;
-
-pub use text::StdoutReporter;
+pub use text::StdioReporter;
 pub use text::StringReporter;
 
 pub const DONTPRINT_TAG: &str = "dontprint";
 
-#[async_trait::async_trait]
+use crate::task_tree::TaskInternal;
+use std::sync::Arc;
+
 pub trait Reporter: Send + Sync {
-    async fn task_start(&self, _task: Arc<TaskInternal>) {}
-    async fn task_end(&self, _task: Arc<TaskInternal>) {}
+    fn task_start(&self, _task: Arc<TaskInternal>) {}
+    fn task_end(&self, _task: Arc<TaskInternal>) {}
+    fn task_progress(&self, _task: Arc<TaskInternal>) {}
 }
